The changelog format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

This project uses [Semantic Versioning](https://semver.org/) - MAJOR.MINOR.PATCH

# Changelog

## 0.6.0 (2026-01-15)


### Added

- Add support for reset the ufw rules via `ufw.reset` execution module.

## 0.5.1 (2026-01-15)

No significant changes.
